send_to_path

Function send_to_path 

pub async fn send_to_path<P: AsRef<Path>>(
    request: &Request,
    socket_path: P,
) -> Result<Response, IpcError>
Send a request to the daemon at a specific socket path

Arguments

  • request - The request to send to the daemon
  • socket_path - Path to the Unix domain socket

Returns

Returns the response from the daemon or an IpcError if communication fails