Function is_daemon_running
Source pub async fn is_daemon_running<P: AsRef<Path>>(socket_path: Option<P>) -> bool
Check if the daemon is running by attempting to connect to its socket
Arguments
socket_path - Optional custom socket path, defaults to DEFAULT_SOCKET_PATH
Returns
Returns true if the daemon is running, false otherwise